@@ -1,13 +1,24 @@
 # Copyright Contributors to the Amundsen project.
 # SPDX-License-Identifier: Apache-2.0
 
-from typing import List, Optional, Dict
+from typing import Any, List, Optional, Dict
 
 import attr
 
 from marshmallow3_annotations.ext.attrs import AttrsSchema
 
 
+@attr.s(auto_attribs=True, kw_only=True)
+class HighlightOptions:
+    enable_highlight: bool = False
+
+
+class HighlightOptionsSchema(AttrsSchema):
+    class Meta:
+        target = HighlightOptions
+        register_as_scheme = True
+
+
 @attr.s(auto_attribs=True, kw_only=True)
 class Filter:
     name: str
@@ -28,6 +39,8 @@ class SearchRequest:
     page_index: Optional[int] = 0
     results_per_page: Optional[int] = 10
     filters: List[Filter] = []
+    # highlight options are defined per resource
+    highlight_options: Optional[Dict[str, HighlightOptions]]
 
 
 class SearchRequestSchema(AttrsSchema):
@@ -41,7 +54,7 @@ class SearchResponse:
     msg: str
     page_index: int
     results_per_page: int
-    results: Dict  # type: ignore
+    results: Dict[str, Any]
     status_code: int
 
 
